# R script for concatenating cpDNA haplotypes and assigning concatenated haplotypes to individuals based on HRM clustering
# Author: Dr A. J. Potts 
# Provided as suplementary material for the following publication doi: https://doi.org/10.1101/2020.02.05.921080
# There is no support for this script and any queries should be directeed at the corrosponding author of the above mentioned publication

#### concatenating SEQ data ####
library(ape)

#Set your working directory to the location your .fasta files are stored
#Read sequence data for each region
#Each haplotype per region should be named based on the concatenated haplotype they would belong to, make sure names are the same between the two files
y <- read.dna("Haplotypes from cpDNA region 1.fasta", format = "fasta")
x <- read.dna("Haplotypes from cpDNA region 2.fasta", format = "fasta")

# make sure names are the same between the two files
z <- cbind(x,y)
write.dna(z,file="Concatenated haplotypes for cpDNA regions 1 and 2.fasta",format="fasta", nbcol=-1,colse="")
z
checkAlignment(z)

#make sure the file is saving correctly
z <- read.dna("Concatenated haplotypes for cpDNA regions 1 and 2.fasta", format="fasta")
z
checkAlignment(z)

#### linking haplotypes to individuals ####
# make sure to set the working directory to where the "Concatenated haplotypes for cpDNA regions 1 and 2.fasta" and "Concatenated haplotype assignment based on HRM clustering.csv" files are stored 

haps <-read.dna("Concatenated haplotypes for cpDNA regions 1 and 2.fasta",format="fasta")
dat <- read.csv("Concatenated haplotype assignment based on HRM clustering.csv")

if(sum(!unique(dat$Haplotype)%in%rownames(haps))>0) warning("Some haplotypes in the .csv are NOT PRESENT IN THE FASTA FILE")
# Removing haplotypes in the csv not present in the fasta file
dat <- subset(dat,Haplotype%in%rownames(haps))

for (i in 1:nrow(dat)) {
  if (i==1) {
    newalignment <- haps[dat[i,"Haplotype"],]
  } else {
    newalignment <- rbind(newalignment,haps[dat[i,"Haplotype"],])
  }
}
rownames(newalignment) <- apply(dat,1,paste,collapse="_")

#check the alignment of the output in condon!!!
#reduce all indels to single BP
write.dna(newalignment,file="Concatednated haplotype assignment for all accessions.fasta",format="fasta",colsep="",nbcol=-1)
